.. _Python: https://www.python.org/
.. _Django: https://www.djangoproject.com/
.. _Django REST framework: https://www.django-rest-framework.org/
.. _bigtree: https://bigtree.readthedocs.io/
.. _Deovi: https://deovi.readthedocs.io/


============
Django Deovi
============

A Django interface to load `Deovi`_ dumps and browse data.


Dependancies
************

* `Python`_>=3.10;
* `Django`_>=4.2;
* `bigtree`_>=0.10.3;
* `Deovi`_>=0.7.0;


Links
*****

* Read the documentation on `Read the docs <https://django-deovi.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/django-deovi>`_;
* Clone it on its `Github repository <https://github.com/sveetch/django-deovi>`_;
